import unittest
from lxml import etree
from signxml_sunat import XMLSigner, XMLVerifier

class TestSignXMLSunat(unittest.TestCase):
    def test_sign(self):
        signed_doc = XMLSigner().sign('doc.xml', 'rsakey.pem', 'rsacert.pem')
        signed_doc_str = etree.tostring(signed_xml, xml_declaration=True, encoding='ISO-8859-1', pretty_print=True)
        result_signed_doc_str = open('signed_doc.xml').read()

        self.assertEqual(signed_doc, result_signed_doc_str)

    def test_verify(self):
        verify = XMLVerifier().verify('sunat_signed.xml', 'rsapub.pem')

        self.assertTrue(verify) 

if __name__ == '__main__':
    unittest.main()


import setuptools

setuptools.setup(
    name='signxml_sunat',
    version='1.0.2',
    author='@danilobrinu',
    author_email='ddbn.c2@gmail.com',
    description='SUNAT - sign and verify xml',
    long_description=open('README.rst').read(),
    install_requires=[
        'lxml >= 4.2.5',
        'xmlsec >= 1.3.52'
    ],
    url='https://github.com/danilobrinu/signxml_sunat',
    packages=setuptools.find_packages(exclude=['test']),
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
)